mirror of
https://github.com/opencv/opencv.git
synced 2026-07-31 08:13:04 +04:00
Misc. modules/ cont. pt2
Found via `codespell`
This commit is contained in:
@@ -700,7 +700,7 @@ CV_EXPORTS Ptr<TemplateMatching> createTemplateMatching(int srcType, int method,
|
||||
|
||||
/** @brief Performs bilateral filtering of passed image
|
||||
|
||||
@param src Source image. Supports only (channles != 2 && depth() != CV_8S && depth() != CV_32S
|
||||
@param src Source image. Supports only (channels != 2 && depth() != CV_8S && depth() != CV_32S
|
||||
&& depth() != CV_64F).
|
||||
@param dst Destination imagwe.
|
||||
@param kernel_size Kernel window size.
|
||||
|
||||
@@ -134,7 +134,7 @@ namespace clahe
|
||||
cudaSafeCall( cudaDeviceSynchronize() );
|
||||
}
|
||||
|
||||
__global__ void tranformKernel(const PtrStepSzb src, PtrStepb dst, const PtrStepb lut, const int2 tileSize, const int tilesX, const int tilesY)
|
||||
__global__ void transformKernel(const PtrStepSzb src, PtrStepb dst, const PtrStepb lut, const int2 tileSize, const int tilesX, const int tilesY)
|
||||
{
|
||||
const int x = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
const int y = blockIdx.y * blockDim.y + threadIdx.y;
|
||||
@@ -173,9 +173,9 @@ namespace clahe
|
||||
const dim3 block(32, 8);
|
||||
const dim3 grid(divUp(src.cols, block.x), divUp(src.rows, block.y));
|
||||
|
||||
cudaSafeCall( cudaFuncSetCacheConfig(tranformKernel, cudaFuncCachePreferL1) );
|
||||
cudaSafeCall( cudaFuncSetCacheConfig(transformKernel, cudaFuncCachePreferL1) );
|
||||
|
||||
tranformKernel<<<grid, block, 0, stream>>>(src, dst, lut, tileSize, tilesX, tilesY);
|
||||
transformKernel<<<grid, block, 0, stream>>>(src, dst, lut, tileSize, tilesX, tilesY);
|
||||
cudaSafeCall( cudaGetLastError() );
|
||||
|
||||
if (stream == 0)
|
||||
|
||||
@@ -330,7 +330,7 @@ void cv::cuda::meanShiftSegmentation(InputArray _src, OutputArray _dst, int sp,
|
||||
std::vector<SegmLink> edges;
|
||||
edges.reserve(g.numv);
|
||||
|
||||
// Prepare edges connecting differnet components
|
||||
// Prepare edges connecting different components
|
||||
for (int v = 0; v < g.numv; ++v)
|
||||
{
|
||||
int c1 = comps.find(v);
|
||||
@@ -342,7 +342,7 @@ void cv::cuda::meanShiftSegmentation(InputArray _src, OutputArray _dst, int sp,
|
||||
}
|
||||
}
|
||||
|
||||
// Sort all graph's edges connecting differnet components (in asceding order)
|
||||
// Sort all graph's edges connecting different components (in asceding order)
|
||||
std::sort(edges.begin(), edges.end());
|
||||
|
||||
// Exclude small components (starting from the nearest couple)
|
||||
|
||||
Reference in New Issue
Block a user